@@ -1,4 +1,4 @@
 from ConfigParser import ConfigParser
 
 config = ConfigParser()
-config.read('/etc/dofler.config')
\ No newline at end of file
+config.read('/etc/dofler/dofler.conf')
\ No newline at end of file
